@@ -333,101 +333,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r = response.json()
         return pd.DataFrame(r['payload']['data'])
 
-    def load_dataset(self, dataset_slug, aliases:list=[], filters:list=[], limit=50):
-
-        '''
-        str : dataset_slug ("my_dataset")
-        list : aliases (["alias of the column", "column 2"])
-        list : filters ([{field: {column: "CONTACTS", alias: null, aggregation: null,…}, operator: "EQ", type: "NUMERIC",…}])
-        '''
-
-        dataset_id = self.get_dataset_by_slug(self._slug, dataset_slug)
-
-        if(dataset_id == None):
-
-            s = requests.Session()
-            s.keep_alive = False
-            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-            s.mount('https://', HTTPAdapter(max_retries=retries))
-
-            url = self._base_url_askdata + '/smartbot/agents/agentslug/'+self._slug+'/datasetslug/'+dataset_slug
-            logging.info("URL {}".format(url))
-
-            headers = {"Authorization": "Bearer" + " " + self._token}
-            response = s.get(url=url, headers=headers)
-            response.raise_for_status()
-            r = response.json()
-
-            try:
-                 dataset_id = r["datasetId"]
-            except:
-                logging.error("Please insert a correct dataset slug")
-                return
-        else:
-            dataset_id = dataset_id
-
-        if(aliases==[]):
-            return self._load_dataset(dataset_id)
-
-        dataset_id = dataset_id
-        url_get = self.smart_insight_url + "/composed_queries?datasetId=" + dataset_id
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {"Authorization": "Bearer" + " " + self._token}
-        response = s.get(url=url_get, headers=headers)
-        response.raise_for_status()
-        r = response.json()
-
-        qc_id = r["qc"]["id"]
-        logging.info(qc_id)
-
-        body = {
-            "datasets": [{"dataset": dataset_id}],
-            "id": qc_id,
-            "orderBy": None,
-            "relationships": None,
-            "where": filters,
-            "limit": limit
-        }
-        fields = []
-        for alias in aliases:
-            fields.append({"column": str(alias).upper(), "alias": alias, "aggregation": None, "dataset": dataset_id})
-
-        body["fields"] = fields
-
-        url_post = self.smart_insight_url + "/composed_queries"
-
-        logging.info("CALLING {}".format(url_post))
-        logging.info(body)
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {"Authorization": "Bearer" + " " + self._token}
-        response = s.post(url=url_post, json=body, headers=headers)
-        response.raise_for_status()
-
-        preview_url= self.smart_insight_url+"/composed_queries/"+qc_id+"/preview"
-
-        logging.info("CALLING {}".format(preview_url))
-
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        headers = {"Authorization": "Bearer" + " " + self._token}
-        response = s.post(url=preview_url, json={}, headers=headers)
-        response.raise_for_status()
-
-        r = response.json()
-        return pd.DataFrame(r['data'])
-
     def get_dataset_by_slug(self, agent_slug, slug: str):
         s = requests.Session()
         s.keep_alive = False
@@ -1052,6 +957,19 @@ class Askdata(SignUp):
 
         return df.merge(df_query, how, on, left_on, right_on)
 
+    def load_dataset(self, workspace_slug, dataset_slug):
+        all_fields = self.get_columns(workspace_slug, dataset_slug)["code"]
+        limit = 1000
+        df = self.query(workspace_slug, dataset_slug, all_fields, limit=limit)
+        if(len(df.index) < 1000):
+            return df
+        else:
+            final_df = df
+            while(len(df.index) == 1000):
+                df = self.query(workspace_slug, dataset_slug, all_fields, limit=(limit+1000), offset=limit)
+                final_df = final_df.append(df)
+            return final_df
+
     def __retrieve_og_columns(self, conditions:list, df:pd.DataFrame):
         formatted_conditions = []
         for condition in conditions:
